daemon

package
v0.11.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 10, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package daemon manages the AgentsAegis proxy background process.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsRunning

func IsRunning(pid int) bool

IsRunning checks if a process with the given PID is running.

func LogFile

func LogFile(configDir string) string

LogFile returns the path to the daemon log file.

func PIDFile

func PIDFile(configDir string) string

PIDFile returns the path to the daemon PID file.

func ReadPID

func ReadPID(configDir string) (int, error)

ReadPID reads the daemon process ID from the PID file.

func RemovePID

func RemovePID(configDir string) error

RemovePID removes the PID file.

func WritePID

func WritePID(configDir string) error

WritePID writes the current process ID to the PID file.

Types

This section is empty.

Jump to